[PATCH] D78083: [CallSite removal][TargetLibraryInfo] Replace ImmutableCallSite with CallBase in one of the getLibFunc signatures.
Craig Topper via Phabricator via llvm-commits
llvm-commits at lists.llvm.org
Wed Apr 15 22:45:41 PDT 2020
This revision was automatically updated to reflect the committed changes.
Closed by commit rG8e1408695cef: [CallSite removal][TargetLibraryInfo] Replace ImmutableCallSite with CallBase… (authored by craig.topper).
Repository:
rG LLVM Github Monorepo
CHANGES SINCE LAST ACTION
https://reviews.llvm.org/D78083/new/
https://reviews.llvm.org/D78083
Files:
llvm/include/llvm/Analysis/TargetLibraryInfo.h
llvm/lib/CodeGen/ExpandMemCmp.cpp
llvm/lib/Transforms/Utils/Local.cpp
llvm/lib/Transforms/Utils/SimplifyLibCalls.cpp
llvm/unittests/Analysis/CGSCCPassManagerTest.cpp
Index: llvm/unittests/Analysis/CGSCCPassManagerTest.cpp
===================================================================
--- llvm/unittests/Analysis/CGSCCPassManagerTest.cpp
+++ llvm/unittests/Analysis/CGSCCPassManagerTest.cpp
@@ -12,6 +12,7 @@
#include "llvm/AsmParser/Parser.h"
#include "llvm/IR/Function.h"
#include "llvm/IR/InstIterator.h"
+#include "llvm/IR/Instructions.h"
#include "llvm/IR/LLVMContext.h"
#include "llvm/IR/Module.h"
#include "llvm/IR/PassManager.h"
Index: llvm/lib/Transforms/Utils/SimplifyLibCalls.cpp
===================================================================
--- llvm/lib/Transforms/Utils/SimplifyLibCalls.cpp
+++ llvm/lib/Transforms/Utils/SimplifyLibCalls.cpp
@@ -1943,7 +1943,7 @@
Intrinsic::ID ArgID = Arg->getIntrinsicID();
LibFunc ArgLb = NotLibFunc;
- TLI->getLibFunc(Arg, ArgLb);
+ TLI->getLibFunc(*Arg, ArgLb);
// log(pow(x,y)) -> y*log(x)
if (ArgLb == PowLb || ArgID == Intrinsic::pow) {
Index: llvm/lib/Transforms/Utils/Local.cpp
===================================================================
--- llvm/lib/Transforms/Utils/Local.cpp
+++ llvm/lib/Transforms/Utils/Local.cpp
@@ -2555,7 +2555,7 @@
// marked as 'gc-leaf-function.' All available Libcalls are
// GC-leaf.
LibFunc LF;
- if (TLI.getLibFunc(ImmutableCallSite(Call), LF)) {
+ if (TLI.getLibFunc(*Call, LF)) {
return TLI.has(LF);
}
Index: llvm/lib/CodeGen/ExpandMemCmp.cpp
===================================================================
--- llvm/lib/CodeGen/ExpandMemCmp.cpp
+++ llvm/lib/CodeGen/ExpandMemCmp.cpp
@@ -824,7 +824,7 @@
continue;
}
LibFunc Func;
- if (TLI->getLibFunc(ImmutableCallSite(CI), Func) &&
+ if (TLI->getLibFunc(*CI, Func) &&
(Func == LibFunc_memcmp || Func == LibFunc_bcmp) &&
expandMemCmp(CI, TTI, TL, &DL, PSI, BFI)) {
return true;
Index: llvm/include/llvm/Analysis/TargetLibraryInfo.h
===================================================================
--- llvm/include/llvm/Analysis/TargetLibraryInfo.h
+++ llvm/include/llvm/Analysis/TargetLibraryInfo.h
@@ -13,8 +13,8 @@
#include "llvm/ADT/DenseMap.h"
#include "llvm/ADT/Optional.h"
#include "llvm/ADT/Triple.h"
-#include "llvm/IR/CallSite.h"
#include "llvm/IR/Function.h"
+#include "llvm/IR/InstrTypes.h"
#include "llvm/IR/Module.h"
#include "llvm/IR/PassManager.h"
#include "llvm/Pass.h"
@@ -287,11 +287,11 @@
return Impl->getLibFunc(FDecl, F);
}
/// If a callsite does not have the 'nobuiltin' attribute, return if the
/// called function is a known library function and set F to that function.
- bool getLibFunc(ImmutableCallSite CS, LibFunc &F) const {
- return !CS.isNoBuiltin() && CS.getCalledFunction() &&
- getLibFunc(*(CS.getCalledFunction()), F);
+ bool getLibFunc(const CallBase &CB, LibFunc &F) const {
+ return !CB.isNoBuiltin() && CB.getCalledFunction() &&
+ getLibFunc(*(CB.getCalledFunction()), F);
}
/// Disables all builtins.
-------------- next part --------------
A non-text attachment was scrubbed...
Name: D78083.257962.patch
Type: text/x-patch
@@ -287,11 +287,11 @@
return Impl->getLibFunc(FDecl, F);
}
- /// If a callsite does not have the 'nobuiltin' attribute, return if the
+ /// If a callbase does not have the 'nobuiltin' attribute, return if the
/// called function is a known library function and set F to that function.
Size: 3067 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20200416/b20eb969/attachment.bin>
More information about the llvm-commits
mailing list